==> SkExtras%201.8.jar: src/me/Funnygatt/SkExtras/SkExtras.java <==
package me.Funnygatt.SkExtras;

import ch.njol.skript.registrations.EventValues;
import ch.njol.skript.util.Getter;
import me.Funnygatt.SkExtras.Effects.*;
import me.Funnygatt.SkExtras.Events.EvtPlayerBlockCollision;
import me.Funnygatt.SkExtras.Events.PlayerCollisionEvent;
import me.Funnygatt.SkExtras.Events.PlayerMoveWhileFrozen;
import me.Funnygatt.SkExtras.Events.RegisterEvents;
import me.Funnygatt.SkExtras.Expressions.ExpDisplayedPrefix;
import me.Funnygatt.SkExtras.Expressions.ExpDisplayedSkull;
import me.Funnygatt.SkExtras.Expressions.ExpDisplayedSuffix;
import me.Funnygatt.SkExtras.Expressions.ExpIsFrozen;
import me.Funnygatt.SkExtras.Utils.FreezeManager;
import me.Funnygatt.SkExtras.Utils.Logger;
import org.bukkit.Bukkit;
import org.bukkit.ChatColor;
import org.bukkit.Location;
import org.bukkit.event.EventHandler;
import org.bukkit.event.Listener;
import org.bukkit.entity.Player;
import org.bukkit.event.block.NotePlayEvent;
import org.bukkit.event.enchantment.PrepareItemEnchantEvent;
import org.bukkit.event.entity.EntityRegainHealthEvent;
import org.bukkit.event.entity.EntityUnleashEvent;
import org.bukkit.event.entity.PlayerLeashEntityEvent;
import org.bukkit.event.entity.PotionSplashEvent;
import org.bukkit.event.entity.SheepRegrowWoolEvent;
import org.bukkit.event.entity.SlimeSplitEvent;
import org.bukkit.event.inventory.BrewEvent;
import org.bukkit.event.inventory.InventoryOpenEvent;
import org.bukkit.event.player.PlayerAchievementAwardedEvent;
import org.bukkit.event.player.PlayerChatTabCompleteEvent;
import org.bukkit.event.player.PlayerMoveEvent;
import org.bukkit.plugin.PluginManager;
import org.bukkit.plugin.java.JavaPlugin;

import ch.njol.skript.Skript;
import ch.njol.skript.expressions.base.SimplePropertyExpression;
import ch.njol.skript.lang.util.SimpleEvent;

import java.util.Collection;

public final class SkExtras extends JavaPlugin implements Listener {

	@Override
	public void onEnable() {
		PluginManager pm = getServer().getPluginManager();
		pm.registerEvents(this, this);

//		public final Logger logger = Logger.getLogger("Minecraft");
//		
//		public final Logger blo = new Logger(this)

		Bukkit.getServer().getPluginManager().registerEvents(this, this);

		Skript.registerAddon((JavaPlugin) Bukkit.getPluginManager().getPlugin("SkExtras"));
		Skript.registerEffect(EffResetRecipes.class, "reset [all] [server] recipes");
		Skript.registerEffect(EffUpdateInventory.class, "update %player% inventory");
		Skript.registerEffect(EffMakeMeAGod.class, "make %player% a god");
		Skript.registerEffect(EffSummonEffect.class, "(summon|play|create|activate|funnygatt|spawn) effect %string% at %location%[[ with] data %integer%]");

		// Skript.registerEffect(EffSetFallDistance.class, "set fall distance of %entities% to %integer%");

		// LibsDisgusies Hooks

		Skript.registerEffect(EffDisguise.class, "disguise %entities% as %string%");
		Skript.registerEffect(EffUndis.class, "undisguise %entities%");

		Skript.registerEvent("Slime Split", SimpleEvent.class, SlimeSplitEvent.class, new String[]{"slime split"});
		Skript.registerEvent("Potion Splash", SimpleEvent.class, PotionSplashEvent.class, new String[]{"potion splash"});
		Skript.registerEvent("Sheep Wool Regrow", SimpleEvent.class, SheepRegrowWoolEvent.class, new String[]{"sheep wool regrow"});
		Skript.registerEvent("Leash Entity", SimpleEvent.class, PlayerLeashEntityEvent.class, new String[]{"[player ]leash"});
		Skript.registerEvent("Unleash Entity", SimpleEvent.class, EntityUnleashEvent.class, new String[]{"unleash"});
		Skript.registerEvent("Regen Health", SimpleEvent.class, EntityRegainHealthEvent.class, new String[]{"health regen"});
		Skript.registerEvent("Brew", SimpleEvent.class, BrewEvent.class, new String[]{"brew"});
		Skript.registerEvent("Enchant Prepare", SimpleEvent.class, PrepareItemEnchantEvent.class, new String[]{"[item ]enchant prepare"});
		Skript.registerEvent("Achievement Award", SimpleEvent.class, PlayerAchievementAwardedEvent.class, new String[]{"achievement[ get]"});
		Logger.info("Registered Move Freeze Event");
		Skript.registerEvent("Note Play", SimpleEvent.class, NotePlayEvent.class, new String[]{"note play"});
		Skript.registerEvent("Inventory Open", SimpleEvent.class, InventoryOpenEvent.class, new String[]{"inventory open"});

		Skript.registerEvent("Tab Complete", SimpleEvent.class, PlayerChatTabCompleteEvent.class, new String[]{"tab complet(e|ion)"});
		EventValues.registerEventValue(PlayerChatTabCompleteEvent.class, String.class, new Getter<String, PlayerChatTabCompleteEvent>() {
			@Override
			public String get(PlayerChatTabCompleteEvent playerChatTabCompleteEvent) {
				return playerChatTabCompleteEvent.getChatMessage();
			}
		}, 0);


		EventValues.registerEventValue(PlayerChatTabCompleteEvent.class, Collection.class, new Getter<Collection, PlayerChatTabCompleteEvent>() {
			@Override
			public Collection get(PlayerChatTabCompleteEvent playerChatTabCompleteEvent) {
				return playerChatTabCompleteEvent.getTabCompletions();
			}
		}, 0);
		EventValues.registerEventValue(PlayerChatTabCompleteEvent.class, String.class, new Getter<String, PlayerChatTabCompleteEvent>() {
			@Override
			public String get(PlayerChatTabCompleteEvent playerChatTabCompleteEvent) {
				return playerChatTabCompleteEvent.getLastToken();
			}
		}, 0);


		// Expressions

		// New Freeze
		SimplePropertyExpression.register(ExpIsFrozen.class, Boolean.class, "freeze state", "player");
		SimplePropertyExpression.register(ExpDisplayedPrefix.class, String.class, "displayed prefix", "player");
		SimplePropertyExpression.register(ExpDisplayedSuffix.class, String.class, "displayed suffix", "player");
		SimplePropertyExpression.register(ExpDisplayedSkull.class, String.class, "skull owner", "block");

		// Freeze Events

		RegisterEvents.registerEvents();
		Bukkit.getPluginManager().registerEvents(new PlayerCollisionEvent(), this);

		getServer().getPluginManager().registerEvents(new FreezeListener(), this);
		getServer().getPluginManager().registerEvents(new PlayerCollisionEvent(), this);



		// Doesn't wanna work
		// Horah! Nothing Here that's not working! (for once)

	}
}

==> SkExtras%202.2.jar: src/me/Funnygatt/SkExtras/SkExtras.java <==
package me.Funnygatt.SkExtras;

import ch.njol.skript.registrations.EventValues;
import ch.njol.skript.util.Getter;
import me.Funnygatt.SkExtras.Effects.*;
import me.Funnygatt.SkExtras.Effects.Disguising.*;
import me.Funnygatt.SkExtras.Events.PlayerCollisionEvent;
import me.Funnygatt.SkExtras.Events.RegisterEvents;
import me.Funnygatt.SkExtras.Experimental.Effects.EffGenerateChunk;
import me.Funnygatt.SkExtras.Experimental.Effects.EffLoadChunk;
import me.Funnygatt.SkExtras.Experimental.Effects.EffUnloadChunk;
import me.Funnygatt.SkExtras.Expressions.*;
import org.bukkit.Bukkit;
import org.bukkit.event.Listener;
import org.bukkit.event.block.NotePlayEvent;
import org.bukkit.event.enchantment.PrepareItemEnchantEvent;
import org.bukkit.event.entity.EntityRegainHealthEvent;
import org.bukkit.event.entity.EntityUnleashEvent;
import org.bukkit.event.entity.PlayerLeashEntityEvent;
import org.bukkit.event.entity.PotionSplashEvent;
import org.bukkit.event.entity.SheepRegrowWoolEvent;
import org.bukkit.event.entity.SlimeSplitEvent;
import org.bukkit.event.inventory.BrewEvent;
import org.bukkit.event.inventory.InventoryOpenEvent;
import org.bukkit.event.player.PlayerAchievementAwardedEvent;
import org.bukkit.event.player.PlayerChatTabCompleteEvent;
import org.bukkit.plugin.PluginManager;
import org.bukkit.plugin.java.JavaPlugin;

import ch.njol.skript.Skript;
import ch.njol.skript.expressions.base.SimplePropertyExpression;
import ch.njol.skript.lang.util.SimpleEvent;
import org.bukkit.util.Vector;

import java.util.Collection;

public final class SkExtras extends JavaPlugin implements Listener {

	@Override
	public void onEnable() {
		PluginManager pm = getServer().getPluginManager();
		pm.registerEvents(this, this);

//		public final Logger logger = Logger.getLogger("Minecraft");
//		
//		public final Logger blo = new Logger(this)

		Bukkit.getServer().getPluginManager().registerEvents(this, this);

		Skript.registerAddon((JavaPlugin) Bukkit.getPluginManager().getPlugin("SkExtras"));
		Skript.registerEffect(EffResetRecipes.class, "reset [all] [server] recipes");
		Skript.registerEffect(EffUpdateInventory.class, "update %player% inventory");
		Skript.registerEffect(EffMakeMeAGod.class, "make %player% a god");
		Skript.registerEffect(EffSummonEffect.class, "(summon|play|create|activate|funnygatt|spawn) effect %string% at %locations%[[ with] data %integer%]");
		Skript.registerEffect(EffGenerateChunk.class, "generate chunk at %location%");
		Skript.registerEffect(EffLoadChunk.class, "load chunk at %location%");
		Skript.registerEffect(EffUnloadChunk.class, "unload chunk at %location%");
		//Skript.registerEffect(EffSetGamerule.class, "set gamerul");

		// Skript.registerEffect(EffSetFallDistance.class, "set fall distance of %entities% to %integer%");

		// LibsDisgusies Hooks

		//Skript.registerEffect(EffNewDisguise.class, "disguise %entities% as[ a] %string%[ to %players%]", "disguise %entities% as[ a] baby %string%[ to %players%]", "disguise %entities% as[ a] (%itemtype% falling block|falling block of %itemtype%)", "undisguise %entities%");

		Skript.registerEffect(EffUndis.class, "undis[guise] %entities%");
		Skript.registerEffect(EffDisguise.class, "dis[guise] %entities% as[ a] %string%");

		//Skript.registerEffect(EffDisguiseOptions.class, "disguise %entities% as %string% with options %boolean%, %boolean%, %boolean%[ to %entities%]");
		//Skript.registerEffect(EffBabyDisguise.class, "disguise %entities% as [a ]baby %string%[ to %entities%]");
		//
		//Skript.registerEffect(EffDisguiseFalling.class, "disguise %entities% as[ a] (%itemtype% falling block|falling block of %itemtype%)");//[ to %players%]");
		//Skript.registerEffect(EffUndis.class, "undisguise %entities%");

		Skript.registerEvent("Slime Split", SimpleEvent.class, SlimeSplitEvent.class, new String[]{"slime split"});
		Skript.registerEvent("Potion Splash", SimpleEvent.class, PotionSplashEvent.class, new String[]{"potion splash"});
		Skript.registerEvent("Sheep Wool Regrow", SimpleEvent.class, SheepRegrowWoolEvent.class, new String[]{"sheep wool regrow"});
		Skript.registerEvent("Leash Entity", SimpleEvent.class, PlayerLeashEntityEvent.class, new String[]{"[player ]leash"});
		Skript.registerEvent("Unleash Entity", SimpleEvent.class, EntityUnleashEvent.class, new String[]{"unleash"});
		Skript.registerEvent("Regen Health", SimpleEvent.class, EntityRegainHealthEvent.class, new String[]{"health regen"});
		Skript.registerEvent("Brew", SimpleEvent.class, BrewEvent.class, new String[]{"brew"});
		Skript.registerEvent("Enchant Prepare", SimpleEvent.class, PrepareItemEnchantEvent.class, new String[]{"[item ]enchant prepare"});
		Skript.registerEvent("Achievement Award", SimpleEvent.class, PlayerAchievementAwardedEvent.class, new String[]{"achievement[ get]"});
		Skript.registerEvent("Note Play", SimpleEvent.class, NotePlayEvent.class, new String[]{"note play"});
		Skript.registerEvent("Inventory Open", SimpleEvent.class, InventoryOpenEvent.class, new String[]{"inventory open"});

		Skript.registerEvent("Tab Complete", SimpleEvent.class, PlayerChatTabCompleteEvent.class, new String[]{"tab complet(e|ion)"});
		EventValues.registerEventValue(PlayerChatTabCompleteEvent.class, String.class, new Getter<String, PlayerChatTabCompleteEvent>() {
			@Override
			public String get(PlayerChatTabCompleteEvent playerChatTabCompleteEvent) {
				return playerChatTabCompleteEvent.getChatMessage();
			}
		}, 0);


		EventValues.registerEventValue(PlayerChatTabCompleteEvent.class, Collection.class, new Getter<Collection, PlayerChatTabCompleteEvent>() {
			@Override
			public Collection get(PlayerChatTabCompleteEvent playerChatTabCompleteEvent) {
				return playerChatTabCompleteEvent.getTabCompletions();
			}
		}, 0);
		EventValues.registerEventValue(PlayerChatTabCompleteEvent.class, String.class, new Getter<String, PlayerChatTabCompleteEvent>() {
			@Override
			public String get(PlayerChatTabCompleteEvent playerChatTabCompleteEvent) {
				return playerChatTabCompleteEvent.getLastToken();
			}
		}, 0);


		// Expressions

		// New Freeze
		SimplePropertyExpression.register(ExpIsFrozen.class, Boolean.class, "freeze state", "player");
		SimplePropertyExpression.register(ExpDisplayedPrefix.class, String.class, "displayed prefix", "player");
		SimplePropertyExpression.register(ExpDisplayedSuffix.class, String.class, "displayed suffix", "player");
		SimplePropertyExpression.register(ExpDisplayedSkull.class, String.class, "skull owner", "block");
		//SimplePropertyExpression.register(ExpGetDisguise.class, String.class, "disguise", "players");
		SimplePropertyExpression.register(ExpVelocity.class, Vector.class, "velocity", "entity");
		// Freeze Events

		RegisterEvents.registerEvents();
		Bukkit.getPluginManager().registerEvents(new PlayerCollisionEvent(), this);

		getServer().getPluginManager().registerEvents(new FreezeListener(), this);
		getServer().getPluginManager().registerEvents(new PlayerCollisionEvent(), this);



		// Doesn't wanna work
		// Horah! Nothing Here that's not working! (for once)

	}
}
